@@ -22,20 +22,23 @@
 #ifndef KCUBEBOXWIDGET_H
 #define KCUBEBOXWIDGET_H
 
+#include <KSvgRenderer>
+#include <kgametheme.h>
+#include <QTime> // IDW
+
 #include "cubeboxbase.h"
 #include "kcubewidget.h"
 #include "brain.h"
-#include <qwidget.h>
+#include <QWidget>
+//Added by qt3to4:
+#include <QGridLayout>
+#include <QPaintEvent>
+#include <QResizeEvent>
 
+class KConfigGroup;
 class QGridLayout;
 class CubeBox;
-class QPalette;
 class QTimer;
-class KConfigBase;
-
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
 
 /**
 *@internal
@@ -52,64 +55,62 @@ class KCubeBoxWidget : public QWidget , public CubeBoxBase<KCubeWidget>
 {
    Q_OBJECT
 public:
-   KCubeBoxWidget(const int dim=1,QWidget *parent=0,const char *name=0);
-      
-   KCubeBoxWidget(CubeBox& box, QWidget *parent=0,const char *name=0);
-   KCubeBoxWidget(const KCubeBoxWidget& box,QWidget *parent=0,const char *name=0);
+   explicit KCubeBoxWidget(const int dim=1,QWidget *parent=0);
+
+   explicit KCubeBoxWidget(CubeBox& box, QWidget *parent=0);
+   KCubeBoxWidget(const KCubeBoxWidget& box,QWidget *parent=0);
    virtual ~KCubeBoxWidget();
-   
+
    KCubeBoxWidget& operator= (CubeBox& box);
    KCubeBoxWidget& operator= ( const KCubeBoxWidget& box);
-   
+
    /**
    * reset cubebox for a new game
    */
    void reset();
-  
+
    /** undo last move */
    void undo();
-   
+
    /**
-   * set colors that are used to show owners of the cubes
-   *
-   * @param forWhom for which player the color should be set
-   * @param color  color for player one
+   * Set colors that are used to show owners of the cubes.
    */
-   void setColor(Player forWhom,QPalette color);
+   void setColors ();
+
    /**
    * sets number of Cubes in a row/column to 'size'.
    */
    virtual void setDim(int dim);
-  
+
    /**
    * sets player 'player' as computer or human
    *
-   * @param player 
+   * @param player
    * @param flag: true for computer, false for human
    */
    void setComputerplayer(Player player,bool flag);
-    
+
    /** returns current skill, according to Prefs::EnumSkill */
    int skill() const;
 
    /** returns true if player 'player' is a computerPlayer */
    bool isComputer(Player player) const;
-  
+
    /** returns true if CubeBox is doing a move or getting a hint */
    bool isActive() const;
    bool isMoving() const;
 
-   /** returns current Color for Player forWhom */
-   QPalette color(Player forWhom);
-
    /**
    * checks if 'player' is a computerplayer an computes next move if TRUE
    */
    void checkComputerplayer(Player player);
- 
-   inline void saveGame(KConfigBase *c) { saveProperties(c); };
-   inline void restoreGame(KConfigBase *c) { readProperties(c); }; 
-  
+
+   inline void saveGame(KConfigGroup&c) { saveProperties(c); }
+   inline void restoreGame(const KConfigGroup&c) { readProperties(c); }
+
+   void makeStatusPixmaps (const int width);
+   const QPixmap & playerPixmap (const int p);
+
 public slots:
    /** stops all activities like getting a hint or doing a move */
    void stopActivities();
@@ -118,11 +119,12 @@ public slots:
     * this cube
     */
    void getHint();
-  
-  void loadSettings();
-  
+
+   void loadSettings();
+
 signals:
    void playerChanged(int newPlayer);
+   void colorChanged(int player);
    void playerWon(int player);
    void startedMoving();
    void startedThinking();
@@ -132,24 +134,45 @@ signals:
 protected:
    virtual QSize sizeHint() const;
    virtual void deleteCubes();
-   virtual void initCubes(); 
+   virtual void initCubes();
+   virtual void paintEvent (QPaintEvent * event);
+   virtual void resizeEvent (QResizeEvent * event);
 
-   void saveProperties(KConfigBase *);
-   void readProperties(KConfigBase *);
+   void saveProperties(KConfigGroup&);
+   void readProperties(const KConfigGroup&);
 
 protected slots:
    /** sets the cursor to an waitcursor */
    void setWaitCursor();
    /** restores the original cursor */
    void setNormalCursor();
-  
+
 private:
    void init();
- 
-   QGridLayout *layout;
+
+   KSvgRenderer svg;
+   KGameTheme theme;		// A graphics theme for KJumpingCube.
+   QTime t; // IDW
+   void makeSVGBackground (const int w, const int h);
+   void makeSVGCubes (const int width);
+   void colorImage (QImage & img, const QColor & c, const int w);
+   void reCalculateGraphics (const int w, const int h);
+
+   int sWidth;			// Width of status pixmaps (used if recoloring).
+   QPixmap status1;		// Status-bar pixmaps for players 1 and 2.
+   QPixmap status2;
+   QPixmap background;		// Pixmap for background.
+   QList<QPixmap> elements;	// Pixmaps for cubes, pips and blinking.
+   QColor color1;		// Player 1's color.
+   QColor color2;		// Player 2's color.
+   QColor color0;		// Color for neutral cubes.
+   bool drawHairlines;		// T = draw hairlines between cubes, F = do not.
+
+   QPoint topLeft;
+   int cubeSize;
    CubeBox *undoBox;
    Brain brain;
-   
+
    QTimer *moveTimer;
    int moveDelay;
    Loop loop;
@@ -157,25 +180,25 @@ private:
    void startLoop();
    /** */
    void stopLoop();
-  
+
    Player changePlayer();
-   bool hasPlayerWon(Player player); 
+   bool hasPlayerWon(Player player);
    bool computerPlOne;
    bool computerPlTwo;
-  
+
    /**
    * increases the cube at row 'row' and column 'column' ,
-   * and starts the Loop for checking the playingfield 
+   * and starts the Loop for checking the playingfield
    */
    void doMove(int row,int column);
 
    void increaseNeighbours(KCubeBoxWidget::Player forWhom,int row,int column);
 
-private slots:   
+private slots:
    void nextLoopStep();
    /**
    * checks if cube at ['row','column'] is clickable by the current player.
-   * if true, it increases this cube and checks the playingfield  
+   * if true, it increases this cube and checks the playingfield
    */
    bool checkClick(int row,int column,bool isClick);
 
