@@ -20,10 +20,11 @@
 */
 
 
-#include <kapplication.h>
-#include <klocale.h>
-#include <kaboutdata.h>
-#include <kcmdlineargs.h>
+#include <KApplication>
+#include <KLocale>
+#include <KAboutData>
+#include <KCmdLineArgs>
+#include <KGlobal>
 
 #include "klines.h"
 
@@ -36,21 +37,23 @@ static const char dummy[] = I18N_NOOP2("Menu title", "&Move");
 
 int main( int argc, char **argv )
 {
-	KAboutData aboutData("klines", I18N_NOOP("Kolor Lines"), LINESVERSION,
-                         description, KAboutData::License_GPL);
-    aboutData.addAuthor("Roman Merzlyakov", I18N_NOOP("Original author"), "roman@sbrf.barrt.ru");
-    aboutData.addAuthor("Roman Razilov", I18N_NOOP("Rewrite and Extension"), "Roman.Razilov@gmx.de");
+    KAboutData aboutData("klines", 0, ki18n("Kolor Lines"), "1.5",
+                         ki18n(description), KAboutData::License_GPL,
+                         ki18n("(c) 2000-2008 The KLines Authors"), KLocalizedString(), "http://games.kde.org/klines");
+    aboutData.addAuthor(ki18n("Roman Merzlyakov"), ki18n("Original author"), "roman@sbrf.barrt.ru");
+    aboutData.addAuthor(ki18n("Roman Razilov"), ki18n("Rewrite and Extension"), "Roman.Razilov@gmx.de");
+    aboutData.addAuthor(ki18n("Dmitry Suzdalev"), ki18n("Rewrite to use QGraphicsView. Current maintainer"), "dimsuz@gmail.com");
+    aboutData.addCredit(ki18n("Eugene Trounev"), ki18n("New SVG artwork for KDE4 version of the game"), "eugene.trounev@gmail.com");
     KCmdLineArgs::init(argc, argv, &aboutData);
 
-    KApplication a;
-    KGlobal::locale()->insertCatalogue("libkdegames");
+    KApplication application;
+    KGlobal::locale()->insertCatalog("libkdegames");
 
-    if (a.isRestored())
-        RESTORE(KLines)
+    if (application.isSessionRestored())
+        RESTORE(KLinesMainWindow)
     else {
-        KLines *w = new KLines;
-        a.setMainWidget(w);
-        w->show();
+        KLinesMainWindow *window = new KLinesMainWindow;
+        window->show();
     }
-    return a.exec();
+    return application.exec();
 }
