@@ -20,43 +20,50 @@
 
 #include "grandf.h"
 #include <klocale.h>
+#include <kdebug.h>
 #include "deck.h"
 #include <kaction.h>
+#include "patsolve/grandf.h"
 #include <assert.h>
-#include "cardmaps.h"
 
-Grandf::Grandf( KMainWindow* parent, const char *name )
-    : Dealer( parent, name )
+Grandf::Grandf( )
+    : DealerScene(  )
 {
-    deck = Deck::new_deck(this);
-    deck->hide();
+    Deck::create_deck(this);
+    Deck::deck()->hide();
 
-    const int distx = cardMap::CARDX() * 14 / 10;
+    const int distx = 14;
 
     for (int i=0; i<4; i++) {
         target[i] = new Pile(i+1, this);
-        target[i]->move(10+(i+1)*distx, 10);
+        target[i]->setPilePos(10+(i+1)*distx, 1);
         target[i]->setType(Pile::KlondikeTarget);
+        target[i]->setObjectName( QString( "target%1" ).arg( i ) ) ;
     }
 
     for (int i=0; i<7; i++) {
         store[i] = new Pile(5+i, this);
-        store[i]->move(10+distx*i, 10 + cardMap::CARDY() * 15 / 10);
+        store[i]->setPilePos(1+distx*i, 16 );
         store[i]->setAddFlags(Pile::addSpread | Pile::several);
         store[i]->setRemoveFlags(Pile::several | Pile::autoTurnTop);
+        store[i]->setObjectName( QString( "store%1" ).arg( i ) ) ;
         store[i]->setCheckIndex(1);
+        store[i]->setReservedSpace( QSizeF( 10, 45 ) );
     }
 
-    setActions(Dealer::Hint | Dealer::Demo | Dealer::Redeal);
+    setActions(DealerScene::Hint | DealerScene::Demo | DealerScene::Redeal);
+    setSolver( new GrandfSolver( this ) );
 }
 
 void Grandf::restart() {
-    deck->collectAndShuffle();
+    Deck::deck()->collectAndShuffle();
     deal();
     numberOfDeals = 1;
 }
 
-void Grandf::redeal() {
+void Grandf::redeal()
+{
+    kDebug(11111) << "redeal\n";
     unmarkAll();
 
     if (numberOfDeals < 3) {
@@ -65,7 +72,7 @@ void Grandf::redeal() {
         numberOfDeals++;
     }
     if (numberOfDeals == 3) {
-        aredeal->setEnabled(false);
+        emit redealPossible(false);
     }
     takeState();
 }
@@ -89,9 +96,9 @@ void Grandf::deal() {
         int i = start;
         do
         {
-            Card *next = deck->nextCard();
+            Card *next = Deck::deck()->nextCard();
             if (next)
-                store[i]->add(next, i != start, true);
+                store[i]->add(next, i != start);
             i += dir;
         } while ( i != stop + dir);
         int t = start;
@@ -101,11 +108,11 @@ void Grandf::deal() {
     }
 
     int i = 0;
-    Card *next = deck->nextCard();
+    Card *next = Deck::deck()->nextCard();
     while (next)
     {
-        store[i+1]->add(next, false , true);
-        next = deck->nextCard();
+        store[i+1]->add(next, false);
+        next = Deck::deck()->nextCard();
         i = (i+1)%6;
     }
 
@@ -115,8 +122,7 @@ void Grandf::deal() {
         if (c)
             c->turn(true);
     }
-    aredeal->setEnabled(true);
-    canvas()->update();
+    emit redealPossible( true );
 }
 
 /*****************************
@@ -133,7 +139,7 @@ void Grandf::collect() {
     for (int pos = 6; pos >= 0; pos--) {
         CardList p = store[pos]->cards();
         for (CardList::ConstIterator it = p.begin(); it != p.end(); ++it)
-            deck->add(*it, true, false);
+            Deck::deck()->add(*it, true);
     }
 }
 
@@ -154,74 +160,14 @@ QString Grandf::getGameState() const
 void Grandf::setGameState( const QString &s)
 {
     numberOfDeals = s.toInt();
-    aredeal->setEnabled(numberOfDeals < 3);
-}
-
-bool Grandf::isGameLost() const
-{
-    // If we can redeal, then nothing's lost yet.
-    if (numberOfDeals <3)
-        return false;
-
-    // Work through the stores, look for killer criteria.
-    for(int i=0; i < 7; i++) {
-
-        /* If this store is empty, then iterate through the other stores and
-         * check if there is a (visible) King card. If so, then we could move
-         * that to the free store (which means a turn is possible, so the
-         * game is not lost yet).
-         */
-        if(store[i]->isEmpty()){
-            for(int i2=1; i2 < 7; i2++) {
-                int j=(i+i2) % 7;
-                CardList p = store[j]->cards();
-                for (CardList::ConstIterator it = p.begin(); it != p.end(); ++it){
-                    Card *c= *it;
-                    if( it != p.begin() && c->realFace() && c->rank() == Card::King)
-                        return false;
-                }
-            }
-        }
-        else{
-            /* If this store has an Ace as it's top card, then we can start a
-             * new target pile!
-             */
-            if(store[i]->top()->rank() == Card::Ace)
-                return false;
-
-            /* Check whether the top card of this store could be added to
-             * any of the target piles.
-             */
-            for(int j=0; j <4; j++)
-                if( !target[j]->isEmpty())
-                    if(store[i]->top()->suit() == target[j]->top()->suit())
-                        if( store[i]->top()->rank() == target[j]->top()->rank() +1)
-                            return false;
-
-            /* Check whether any (group of) cards from another store could
-             * be put onto this store's top card.
-             */
-            for(int i2=1; i2 < 7; i2++) {
-                int j=(i+i2) % 7;
-                CardList p = store[j]->cards();
-                for (CardList::ConstIterator it = p.begin(); it != p.end(); ++it){
-                    Card *c= *it;
-                    if( c->realFace() &&
-                        c->rank() == (store[i]->top()->rank()-1) &&
-                        c->suit() == store[i]->top()->suit() )
-                        return false;
-                }
-            }
-        }
-    }
-    return true; // can't move.
+    emit redealPossible(numberOfDeals < 3);
 }
 
 static class LocalDealerInfo1 : public DealerInfo
 {
 public:
     LocalDealerInfo1() : DealerInfo(I18N_NOOP("&Grandfather"), 1) {}
-    virtual Dealer *createGame(KMainWindow *parent) { return new Grandf(parent); }
+    virtual DealerScene *createGame() { return new Grandf(); }
 } gfdi;
 
 #include "grandf.moc"
