@@ -31,11 +31,13 @@
 
 class KlondikePile;
 
-class Klondike : public Dealer {
+class Klondike : public DealerScene {
+    friend class KlondikeSolver;
+
     Q_OBJECT
 
 public:
-    Klondike( bool easy, KMainWindow* parent=0, const char* name=0);
+    explicit Klondike( bool easy );
 
 public:
     virtual void restart();
@@ -47,14 +49,9 @@ public:
 
     virtual bool cardClicked(Card *);
     virtual void pileClicked(Pile *c);
-    virtual void getHints();
 
     virtual Card *demoNewCards();
 
-    bool tryToDrop(Card *t);
-
-    virtual bool isGameLost() const;
-
 private:
     bool EasyRules;
     bool redealt;
@@ -63,9 +60,20 @@ private:
     Pile* target[4];
 
     KlondikePile *pile;
-    Deck* deck;
     Card::Rank target_tops[4];
     bool noLongerNeeded(Card::Rank r, Card::Suit s );
 };
 
+class KlondikePile : public Pile
+{
+public:
+    KlondikePile( int _index, int _draw, DealerScene* parent);
+    int draw() const { return m_draw; }
+    virtual QSizeF cardOffset( const Card * ) const { return QSizeF( 0, 0 ); }
+    virtual void relayoutCards();
+
+private:
+    int m_draw;
+};
+
 #endif
