@@ -1,56 +1,78 @@
+/*
+ * Permission to use, copy, modify, and distribute this software and its
+ * documentation for any purpose and without fee is hereby granted,
+ * provided that the above copyright notice appear in all copies and that
+ * both that copyright notice and this permission notice appear in
+ * supporting documentation.
+ *
+ * This file is provided AS IS with no warranties of any kind.  The author
+ * shall have no liability with respect to the infringement of copyrights,
+ * trade secrets or any patents by this file or any part thereof.  In no
+ * event will the author be liable for any lost revenue or profits or
+ * other special, indirect and consequential damages.
+*/
 #include "simon.h"
 #include <klocale.h>
 #include <kdebug.h>
 #include "deck.h"
 #include <assert.h>
-#include "cardmaps.h"
+#include "patsolve/simon.h"
 
-Simon::Simon( KMainWindow* parent, const char *name )
-    : Dealer( parent, name )
+Simon::Simon( )
+    : DealerScene( )
 {
-    deck = Deck::new_deck(this);
-    deck->move(10, 10);
-    deck->hide();
+    Deck::create_deck(this, 1, 4);
+    Deck::deck()->setPilePos(1, 1);
+    Deck::deck()->hide();
 
-    const int dist_x = cardMap::CARDX() * 11 / 10 + 1;
+    const qreal dist_x = 11.1;
 
     for (int i=0; i<4; i++) {
         target[i] = new Pile(i+1, this);
-        target[i]->move(10+(i+3)*dist_x, 10);
+        target[i]->setPilePos(1+(i+3)*dist_x, 1);
         target[i]->setRemoveFlags(Pile::disallow);
         target[i]->setAddFlags(Pile::several);
         target[i]->setCheckIndex(0);
         target[i]->setTarget(true);
+        target[i]->setObjectName( QString( "target%1" ).arg( i ) );
     }
 
     for (int i=0; i<10; i++) {
         store[i] = new Pile(5+i, this);
-        store[i]->move(15+dist_x*i, 10 + cardMap::CARDY() * 73 / 50);
+        store[i]->setPilePos(1+dist_x*i, 13.7);
         store[i]->setAddFlags(Pile::addSpread | Pile::several);
         store[i]->setRemoveFlags(Pile::several);
+        store[i]->setReservedSpace( QSizeF( 10, 30 ) );
         store[i]->setCheckIndex(1);
+        store[i]->setObjectName( QString( "store%1" ).arg( i ) );
     }
 
-    setActions(Dealer::Hint | Dealer::Demo);
+    setActions(DealerScene::Hint | DealerScene::Demo);
+    setSolver( new SimonSolver( this ) );
+    setNeededFutureMoves( 6 ); // could be some nonsense moves
 }
 
 void Simon::restart() {
-    deck->collectAndShuffle();
+    Deck::deck()->collectAndShuffle();
     deal();
 }
 
 void Simon::deal() {
-    int piles = 3;
-
-    for (int round = 0; round < 8; round++)
+    for ( int piles = 9; piles >= 3; piles-- )
     {
         for (int j = 0; j < piles; j++)
         {
-            store[j]->add(deck->nextCard(), false, true);
+            Card *c = Deck::deck()->nextCard();
+            store[j]->add(c, false);
         }
-        piles++;
     }
-    assert(deck->isEmpty());
+    for ( int j = 0; j < 10; j++ )
+    {
+        Card *c = Deck::deck()->nextCard();
+        store[j]->add(c, false);
+    }
+
+    assert(Deck::deck()->isEmpty());
 }
 
 bool Simon::checkPrefering( int checkIndex, const Pile *c1, const CardList& c2) const
@@ -109,48 +131,11 @@ bool Simon::checkRemove(int checkIndex, const Pile *p, const Card *c) const
     return true;
 }
 
-bool Simon::isGameLost() const
-{
-	kdDebug(11111) <<"isGameLost" << endl;
-    for (int i=0; i<10; i++) {
-		if(store[i]->isEmpty())
-			return false;
-	kdDebug(11111) <<"store["<<i<<"]" << endl;
-
-		Card *c;
-		Card *top=store[i]->top();
-		int indexi=store[i]->indexOf(top);
-		while(--indexi >=0){
-		kdDebug(11111) <<top->name() << endl;
-			c=store[i]->at(indexi);
-			if(c->suit() == top->suit() &&
-				(top->rank()+1) == c->rank())
-				top=c;
-			else
-				break;
-			}
-
-		kdDebug(11111) <<"selected: " << top->name() << endl;
-		for(int j=1; j <10; j++){
-			int k=(i+j) % 10;
-
-			if(store[k]->isEmpty())
-				return false;
-
-			kdDebug(11111) <<"vs "<<store[k]->top()->name() << endl;
-			if((top->rank() +1) == store[k]->top()->rank())
-				return false;
-			}
-		}
-
-	return true;
-}
-
 static class LocalDealerInfo9 : public DealerInfo
 {
 public:
     LocalDealerInfo9() : DealerInfo(I18N_NOOP("&Simple Simon"), 9) {}
-    virtual Dealer *createGame(KMainWindow *parent) { return new Simon(parent); }
+    virtual DealerScene *createGame() { return new Simon(); }
 } gfi9;
 
 #include "simon.moc"
