@@ -19,10 +19,10 @@
 ---------------------------------------------------------------------------*/
 
 #include "spider.h"
-#include "cardmaps.h"
 #include <klocale.h>
 #include "deck.h"
 #include <kdebug.h>
+#include "patsolve/spider.h"
 
 void SpiderPile::moveCards(CardList &c, Pile *to)
 {
@@ -39,7 +39,7 @@ void SpiderPile::moveCards(CardList &c, Pile *to)
     if (c.last()->rank() == Card::Ace &&
         c.first()->suit() == to->top()->suit() &&
         to->cardsLeft() > 12) {
-            Spider *b = dynamic_cast<Spider*>(dealer());
+            Spider *b = dynamic_cast<Spider*>(dscene());
             if (b) {
                 b->checkPileDeck(to);
             }
@@ -48,57 +48,75 @@ void SpiderPile::moveCards(CardList &c, Pile *to)
 
 //-------------------------------------------------------------------------//
 
-Spider::Spider(int suits, KMainWindow* parent, const char* _name)
-        : Dealer(parent, _name)
+Spider::Spider(int suits)
+    : DealerScene(), m_leg(0), m_redeal(0)
 {
-    const int dist_x = cardMap::CARDX() * 11 / 10 + 1;
-    const int dist_y = cardMap::CARDY() * 11 / 10 + 1;
+    const qreal dist_x = 11.2;
 
-    deck = Deck::new_deck(this, 2, suits);
+    Deck::create_deck(this, 2, suits);
 
     // I deal the cards into 'redeal' piles, so hide the deck
-    deck->setVisible(false);
+    Deck::deck()->setVisible(false);
 
     // Dealing the cards out into 5 piles so the user can see how many
     // sets of 10 cards are left to be dealt out
     for( int column = 0; column < 5; column++ ) {
         redeals[column] = new Pile(column + 1, this);
-        redeals[column]->move(8 + dist_x / 3 * (23 + column), 8 + dist_y * 4.5);
-        redeals[column]->setZ(5-column);
+        redeals[column]->setPilePos( 0 - dist_x / 3 * ( 5 - column ), -1);
+        redeals[column]->setZValue(12 * ( 5-column ));
         redeals[column]->setCheckIndex(0);
         redeals[column]->setAddFlags(Pile::disallow);
         redeals[column]->setRemoveFlags(Pile::disallow);
+        redeals[column]->setObjectName( QString( "redeals%1" ).arg( column ) );
         connect(redeals[column], SIGNAL(clicked(Card*)), SLOT(deckClicked(Card*)));
     }
+    redeals[0]->setReservedSpace( QSizeF( -50, 10 ) );
 
     // The 10 playing piles
     for( int column = 0; column < 10; column++ ) {
         stack[column] = new SpiderPile(column + 6, this);
-        stack[column]->move(8 + dist_x * column, 8);
-        stack[column]->setZ(20);
+        stack[column]->setPilePos(1 + dist_x * column, 1);
+        stack[column]->setZValue(20);
         stack[column]->setCheckIndex(1);
         stack[column]->setAddFlags(Pile::addSpread | Pile::several);
         stack[column]->setRemoveFlags(Pile::several |
-            Pile::autoTurnTop | Pile::wholeColumn);
+                                      Pile::autoTurnTop | Pile::wholeColumn);
+        stack[column]->setObjectName( QString( "stack%1" ).arg( column ) );
+        stack[column]->setReservedSpace( QSizeF( 10, 35 ) );
     }
 
     // The 8 'legs' so named by me because spiders have 8 legs - why
     // else the name Spider?
     for( int column = 0; column < 8; column++ ) {
         legs[column] = new Pile(column + 16, this);
-        legs[column]->move(8 + dist_x / 3 * column, 8 + dist_y * 4.5);
-        legs[column]->setZ(column+1);
+        legs[column]->setPilePos(1 + dist_x / 3 * column, -1);
+        legs[column]->setZValue(column+1);
         legs[column]->setCheckIndex(0);
         legs[column]->setAddFlags(Pile::disallow);
         legs[column]->setRemoveFlags(Pile::disallow);
         legs[column]->setTarget(true);
+        legs[column]->setVisible( false );
+        legs[column]->setZValue(14 * column);
+        legs[column]->setObjectName( QString( "legs%1" ).arg( column ) );
     }
 
     // Moving an A-K run to a leg is not really an autoDrop - the
     // user should have no choice.  Also, it must be moved A first, ...
     // up to K so the King will be on top.
     setAutoDropEnabled(false);
-    setActions(Dealer::Hint | Dealer::Demo );
+    setActions(DealerScene::Hint | DealerScene::Demo );
+    setSolver( new SpiderSolver( this ) );
+}
+
+void Spider::cardStoped(Card * t)
+{
+    for( int column = 0; column < 10; column++ ) {
+        Card *t = stack[column]->top();
+        if (t && !t->isFaceUp())
+           t->flipTo(t->x(), t->y());
+    }
+    t->disconnect(this, SLOT( cardStoped( Card* ) ) );
+    setWaiting( false );
 }
 
 //-------------------------------------------------------------------------//
@@ -129,120 +147,6 @@ bool Spider::checkRemove(int /*checkIndex*/, const Pile *p, const Card *c) const
     return true;
 }
 
-void Spider::getHints()
-{
-    kdDebug(11111) << "get hints" << endl;
-    // first, get runs from each stack
-    CardList cl[10];
-
-    Pile* empty = NULL;
-    for (int column = 0; column < 10; column++) {
-        if (stack[column]->isEmpty())
-           empty = stack[column];
-        else
-            cl[column] = getRun(stack[column]->top());
-    }
-
-    // if I can build a run from Ace->King in one suit then
-    // hint those moves
-    HintList hl;
-    for (int s = Card::Clubs; s <= Card::Spades; s++) {
-        bool bGrowing = true;
-        int vTopNew = 0;
-        int colNew = -1;
-        while (bGrowing && vTopNew < 13) {
-            bGrowing = false;
-            int col = colNew;
-            int vTop = vTopNew;
-            for (int column = 0; column < 10; column++) {
-                if (cl[column].isEmpty() || col == column)
-                    continue;
-                if (cl[column].last()->suit() == s &&
-                    cl[column].last()->rank() <= vTop+1 &&
-                    cl[column].first()->rank() > vTop)
-                {
-                    bGrowing = true;
-                    if (cl[column].first()->rank() > vTopNew) {
-                        colNew = column;
-                        vTopNew = cl[column].first()->rank();
-                    }
-                }
-            }
-            if (bGrowing && vTop)
-                hl.append(new MoveHint(cl[col][vTop-
-                   cl[colNew].last()->rank()+1], stack[colNew]));
-        }
-        if (vTopNew == 13)
-            hints += hl;
-        else
-            for (HintList::Iterator it = hl.begin(); it != hl.end(); ++it)
-                delete *it;
-        hl.clear();
-    }
-
-    // now check to see if a run from one column can go on the end
-    // of a run from another stack
-    for (int column = 0; column < 10; column++) {
-        if (cl[column].isEmpty())
-            continue;
-
-        // if there is an empty column and this stack is on
-        // another card, hint
-        if (empty && cl[column].count() < (uint)stack[column]->cardsLeft()) {
-            newHint(new MoveHint(cl[column].first(), empty));
-            continue;
-        }
-
-        // now see if I can move this stack to any other column
-        for (int c2 = 0; c2 < 10; c2++) {
-            if (c2 == column || cl[c2].isEmpty())
-                continue;
-
-            if (cl[c2].last()->rank() == cl[column].first()->rank()+1)
-            {
-                // I can hint this move - should I?
-                int index = stack[column]->indexOf(cl[column].first());
-
-                // if target pile is the same suit as this card,
-                // or if there are no cards under this one,
-                // or if it couldn't move to where it is now,
-                // or if the card under this one is face down, hint
-                if (cl[c2].last()->suit() == cl[column].first()->suit() ||
-                    index == 0 || stack[column]->at(index-1)->rank() !=
-                    cl[column].first()->rank()+1 ||
-                    !(stack[column]->at(index-1)->realFace()))
-                        newHint(new MoveHint(cl[column].first(), stack[c2]));
-            }
-        }
-    }
-}
-
-MoveHint *Spider::chooseHint()
-{
-    kdDebug(11111) << "choose 1 of " << hints.count() << " hints" << endl;
-    if (hints.isEmpty())
-        return 0;
-
-    // first, choose a card that is moving to the same suit
-    for (HintList::ConstIterator it = hints.begin(); it != hints.end(); ++it)
-    {
-        if (!(*it)->pile()->isEmpty() &&
-            (*it)->pile()->top()->suit() == (*it)->card()->suit())
-            return *it;
-    }
-
-    // second, choose a card that is moving from the base
-    for (HintList::ConstIterator it = hints.begin(); it != hints.end(); ++it)
-    {
-        if ((*it)->card()->source() &&
-            (*it)->card()->source()->at(0) == (*it)->card())
-            return *it;
-    }
-
-    // otherwise, go with a random hint
-    return hints[randseq.getLong(hints.count())];
-}
-
 //-------------------------------------------------------------------------//
 
 QString Spider::getGameState() const
@@ -269,13 +173,14 @@ void Spider::setGameState(const QString &stream)
     } else
         for (; m_redeal < i%10; m_redeal++)
             redeals[m_redeal]->setVisible(false);
+    kDebug(11111) << m_leg << m_redeal;
 }
 
 //-------------------------------------------------------------------------//
 
 void Spider::restart()
 {
-    deck->collectAndShuffle();
+    Deck::deck()->collectAndShuffle();
     deal();
 }
 
@@ -306,11 +211,14 @@ CardList Spider::getRun(Card *c) const
     return result;
 }
 
-void Spider::checkPileDeck(Pile *check)
+bool Spider::checkPileDeck(Pile *check, bool checkForDemo)
 {
-    kdDebug(11111) << "check for run" << endl;
+    if ( checkForDemo && demoActive() )
+        return false;
+
+    //kDebug(11111) << "check for run";
     if (check->isEmpty())
-        return;
+        return false;
 
     if (check->top()->rank() == Card::Ace) {
         // just using the CardList to see if this goes to King
@@ -318,16 +226,25 @@ void Spider::checkPileDeck(Pile *check)
         if (run.first()->rank() == Card::King) {
             legs[m_leg]->setVisible(true);
 
-            // remove this full deck from this pile
-            CardList cl;
-            for (int i = 0; i < 13; i++ ) {
-                cl.append(check->cards().last());
-                check->moveCards(cl, legs[m_leg]);
-                cl.clear();
+            CardList::iterator it = run.end();
+            qreal z = 1;
+            while (it != run.begin()) {
+                --it;
+                legs[m_leg]->add( *it );
+                // ( *it )->setSpread( QSize( 0, 0 ) );
+                ( *it )->moveTo( legs[m_leg]->x(), legs[m_leg]->y(), legs[m_leg]->zValue() + z, 300 + int( z ) * 30 );
+                z += 1;
             }
+            connect( run.first(), SIGNAL(stoped(Card*)), SLOT(cardStoped(Card*)));
+            setWaiting( true );
+            /*if ( demoActive() )
+              newDemoMove( run.first() );*/
             m_leg++;
+
+            return true;
         }
     }
+    return false;
 }
 
 void Spider::dealRow()
@@ -336,7 +253,7 @@ void Spider::dealRow()
         return;
 
     for (int column = 0; column < 10; column++) {
-        stack[column]->add(redeals[m_redeal]->top(), false, true);
+        stack[column]->add(redeals[m_redeal]->top(), false);
 
         // I may put an Ace on a K->2 pile so it could need cleared.
         if (stack[column]->top()->rank() == Card::Ace)
@@ -358,18 +275,18 @@ void Spider::deal()
     int column = 0;
     // deal face down cards (5 to first 4 piles, 4 to last 6)
     for (int i = 0; i < 44; i++ ) {
-        stack[column]->add(deck->nextCard(), true, true);
+        stack[column]->add(Deck::deck()->nextCard(), true);
         column = (column + 1) % 10;
     }
     // deal face up cards, one to each pile
     for (int i = 0; i < 10; i++ ) {
-        stack[column]->add(deck->nextCard(), false, true);
+        stack[column]->add(Deck::deck()->nextCard(), false);
         column = (column + 1) % 10;
     }
     // deal the remaining cards into 5 'redeal' piles
     for (int column = 0; column < 5; column++ )
         for (int i = 0; i < 10; i++ )
-            redeals[column]->add(deck->nextCard(), true, false);
+            redeals[column]->add(Deck::deck()->nextCard(), true);
 
     // make the leg piles invisible
     for (int i = 0; i < 8; i++ )
@@ -381,15 +298,21 @@ void Spider::deal()
 
 Card *Spider::demoNewCards()
 {
-   if (m_leg > 4)
-       return 0;
-   deckClicked(0);
-   return stack[0]->top();
+    for ( int i = 0; i < 10; i++ )
+    {
+        if ( checkPileDeck( stack[i], false ) )
+            return legs[m_leg-1]->top();
+    }
+    kDebug(11111) << m_leg;
+    if (m_redeal > 4)
+        return 0;
+    deckClicked(0);
+    return stack[0]->top();
 }
 
 void Spider::deckClicked(Card*)
 {
-    kdDebug(11111) << "deck clicked " << m_redeal << endl;
+    //kDebug(11111) << "deck clicked" << m_redeal;
     if (m_redeal > 4)
         return;
 
@@ -398,82 +321,25 @@ void Spider::deckClicked(Card*)
     takeState();
 }
 
-bool Spider::isGameLost() const
-{
-    kdDebug(11111) << "isGameLost ?"<< endl;
-
-    // if there are still cards to deal out, you have not lost
-    if (m_redeal < 5)
-        return false;
-
-    // first, get runs from each stack - returning if empty
-    CardList cl[10];
-
-    for (int column = 0; column < 10; column++) {
-        if (stack[column]->isEmpty())
-           return false;
-        cl[column] = getRun(stack[column]->top());
-    }
-
-    // from this point on, I know that none of the columns is empty
-    // now check to see if a run from one column can go on the end
-    // of a run from another stack
-    for (int column = 0; column < 10; column++)
-        for (int c2 = 0; c2 < 10; c2++) {
-            if (c2 == column)
-                continue;
-
-            // if I can move this run to another pile, I'm not done
-            if (cl[c2].last()->rank() == cl[column].first()->rank()+1)
-                return false;
-        }
-
-    // if you can build a run from Ace->King in one suit then
-    // you can clear it and keep playing
-    for (int s = Card::Clubs; s <= Card::Spades; s++) {
-        bool bGrowing = true;
-        int vTop = 0;
-        while (bGrowing && vTop < 13) {
-            bGrowing = false;
-            int column = 0;
-            while (column < 10 && !bGrowing) {
-                if (cl[column].last()->suit() == s &&
-                    cl[column].last()->rank() <= vTop+1 &&
-                    cl[column].first()->rank() > vTop)
-                {
-                    bGrowing = true;
-                    vTop = cl[column].first()->rank();
-                }
-                column++;
-            }
-        }
-        // if you can build such a pile, you can continue
-        if (vTop == 13)
-           return false;
-    }
-
-    return true;
-}
-
 static class LocalDealerInfo15 : public DealerInfo
 {
 public:
     LocalDealerInfo15() : DealerInfo(I18N_NOOP("S&pider (Easy)"), 14) {}
-    virtual Dealer *createGame(KMainWindow *parent) { return new Spider(1, parent); }
+    virtual DealerScene *createGame() { return new Spider(1); }
 } ldi15;
 
 static class LocalDealerInfo16 : public DealerInfo
 {
 public:
     LocalDealerInfo16() : DealerInfo(I18N_NOOP("Spider (&Medium)"), 15) {}
-    virtual Dealer *createGame(KMainWindow *parent) { return new Spider(2, parent); }
+    virtual DealerScene *createGame() { return new Spider(2); }
 } ldi16;
 
 static class LocalDealerInfo17 : public DealerInfo
 {
 public:
     LocalDealerInfo17() : DealerInfo(I18N_NOOP("Spider (&Hard)"), 16) {}
-    virtual Dealer *createGame(KMainWindow *parent) { return new Spider(4, parent); }
+    virtual DealerScene *createGame() { return new Spider(4); }
 } ldi17;
 
 //-------------------------------------------------------------------------//
