@@ -13,36 +13,28 @@
 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 
 #ifndef HIGHSCORES_H
 #define HIGHSCORES_H
 
-
 #include <kexthighscore.h>
 #include <kdemacros.h>
-#include "SuperEngine.h"
-
+#include <QStringList>
 
 namespace KExtHighscore
 {
 
-class KDE_EXPORT ExtManager : public Manager
+class ExtManager : public Manager
 {
- public:
-  ExtManager();
+public:
+    ExtManager();
 
- private:
-  QString gameTypeLabel(uint gameTye, LabelType) const;
-  void convertLegacy(uint gameType);
-    
-  struct Data {
-    const char  *label;
-    const char  *icon;
-  };
-  static const Data  DATA[SuperEngine::NbStrengths];
+private:
+    virtual QString gameTypeLabel(uint gameTye, LabelType) const;
+    QStringList m_typeLabels;
 };
 
 }
