@@ -12,7 +12,9 @@
  *
  *******************************************************************
  *
- * created 1997 by Mario Weilguni <mweilguni@sime.com>
+ * Copyright (C)  1997 by Mario Weilguni <mweilguni@sime.com>
+ * Copyright (C) 2002-2004 Dave Corrie  <kde@davecorrie.com>
+ * Copyright (C) 2007 Mauricio Piacentini <mauricio@tabuleiro.com>
  *
  *******************************************************************
  *
@@ -36,33 +38,46 @@
  *******************************************************************
  */
 
-#include <kapplication.h>
+#include "app.h"
+
+#include <kactioncollection.h>
+#include <kstandardaction.h>
 #include <kseparator.h>
 #include <kmessagebox.h>
 #include <kconfig.h>
 #include <kaction.h>
-#include <kstdgameaction.h>
+#include <kstandardgameaction.h>
 #include <khighscore.h>
 #include <kdebug.h>
-#include <kkeydialog.h>
-#include <kpopupmenu.h>
+#include <kshortcutsdialog.h>
+#include <kmenu.h>
 #include <kstatusbar.h>
 #include <klocale.h>
 #include <kpushbutton.h>
-#include <kstdguiitem.h>
+#include <KStandardGuiItem>
 #include <kconfigdialog.h>
 
-#include <qlayout.h>
-#include <qtimer.h>
-#include <qlineedit.h>
+#include <QTimer>
+#include <KLineEdit>
 
 #include <cmath>
-
-#include "app.h"
+#include <kglobal.h>
 #include "prefs.h"
-#include "settings.h"
+#include "ui_settings.h"
 
-App::App(QWidget *parent, const char *name) : KMainWindow(parent, name),
+#include <kmahjonggconfigdialog.h>
+
+class Settings : public QWidget, public Ui::Settings
+{
+public:
+	Settings(QWidget *parent)
+		: QWidget(parent)
+	{
+		setupUi(this);
+	}
+};
+
+App::App(QWidget *parent) : KXmlGuiWindow(parent),
    cheat(false)
 {
 	highscoreTable = new KHighscore(this);
@@ -75,56 +90,73 @@ App::App(QWidget *parent, const char *name) : KMainWindow(parent, name),
 	else
 		readOldHighscore();
 
-	statusBar()->insertItem("", SBI_TIME);
-	statusBar()->insertItem("", SBI_TILES);
-	statusBar()->insertFixedItem(i18n(" Cheat mode "), SBI_CHEAT);
-	statusBar()->changeItem("", SBI_CHEAT);
+	setupStatusBar();
+	setupActions();
 
-	initKAction();
-
-	board = new Board(this, "board");
-	loadSettings();
+	board = new Board(this);
+	board->setObjectName( "board" );
 
 	setCentralWidget(board);
 
 	setupGUI();
 
 	connect(board, SIGNAL(changed()), this, SLOT(enableItems()));
+	connect(board, SIGNAL(tilesDontMatch()), this, SLOT(notifyTilesDontMatch()));
+	connect(board, SIGNAL(invalidMove()), this, SLOT(notifyInvalidMove()));
+	connect(board, SIGNAL(selectATile()), this, SLOT(notifySelectATile()));
+	connect(board, SIGNAL(selectAMatchingTile()), this, SLOT(notifySelectAMatchingTile()));
+	connect(board, SIGNAL(selectAMove()), this, SLOT(notifySelectAMove()));
 
 	QTimer *t = new QTimer(this);
 	t->start(1000);
 	connect(t, SIGNAL(timeout()), this, SLOT(updateScore()));
 	connect(board, SIGNAL(endOfGame()), this, SLOT(slotEndOfGame()));
-	connect(board, SIGNAL(resized()), this, SLOT(boardResized()));
 
-	kapp->processEvents();
+	qApp->processEvents();
 
 	updateScore();
 	enableItems();
 }
 
-void App::initKAction()
+void App::setupStatusBar()
+{
+	gameTipLabel= new QLabel(i18n("Select a tile"), statusBar());
+	statusBar()->addWidget(gameTipLabel, 1);
+	
+	gameTimerLabel = new QLabel(i18n("Time: 0:00:00"), statusBar());
+	statusBar()->addWidget(gameTimerLabel);
+	
+	gameTilesLabel = new QLabel(i18n("Removed: 0/0"), statusBar());
+	statusBar()->addWidget(gameTilesLabel);
+	
+	gameCheatLabel = new QLabel(i18n("Cheat mode"), statusBar());
+	statusBar()->addWidget(gameCheatLabel);
+	gameCheatLabel->hide();
+}
+
+void App::setupActions()
 {
 	// Game
-	KStdGameAction::gameNew(this, SLOT(newGame()), actionCollection());
-	KStdGameAction::restart(this, SLOT(restartGame()), actionCollection());
-	KStdGameAction::pause(this, SLOT(pause()), actionCollection());
-	KStdGameAction::highscores(this, SLOT(hallOfFame()), actionCollection());
-	KStdGameAction::quit(this, SLOT(quitGame()), actionCollection());
+	KStandardGameAction::gameNew(this, SLOT(newGame()), actionCollection());
+	KStandardGameAction::restart(this, SLOT(restartGame()), actionCollection());
+	KStandardGameAction::pause(this, SLOT(pause()), actionCollection());
+	KStandardGameAction::highscores(this, SLOT(hallOfFame()), actionCollection());
+	KStandardGameAction::quit(this, SLOT(close()), actionCollection());
 
 	// Move
-	KStdGameAction::undo(this, SLOT(undo()), actionCollection());
-	KStdGameAction::redo(this, SLOT(redo()), actionCollection());
-	KStdGameAction::hint(this, SLOT(hint()), actionCollection());
+	KStandardGameAction::undo(this, SLOT(undo()), actionCollection());
+	KStandardGameAction::redo(this, SLOT(redo()), actionCollection());
+	KStandardGameAction::hint(this, SLOT(hint()), actionCollection());
 	//new KAction(i18n("Is Game Solvable?"), 0, this,
 	//	SLOT(isSolvable()), actionCollection(), "move_solvable");
 
 #ifdef DEBUGGING
-	(void)new KAction(i18n("&Finish"), 0, board, SLOT(finish()), actionCollection(), "move_finish");
+	// broken ..
+	//(void)new KAction(i18n("&Finish"), 0, board, SLOT(finish()), actionCollection(), "move_finish");
 #endif
 
 	// Settings
-	KStdAction::preferences(this, SLOT(showSettings()), actionCollection());
+	KStandardAction::preferences(this, SLOT(showSettings()), actionCollection());
 }
 
 void App::hallOfFame()
@@ -139,11 +171,6 @@ void App::newGame()
 	enableItems();
 }
 
-void App::quitGame()
-{
-	kapp->quit();
-}
-
 void App::restartGame()
 {
 	board->setUpdatesEnabled(false);
@@ -164,8 +191,7 @@ void App::isSolvable()
 
 void App::pause()
 {
-	bool paused = board->pause();
-	lockMenus(paused);
+	lockMenus(board->pause());
 }
 
 void App::undo()
@@ -196,52 +222,26 @@ void App::hint()
 	enableItems();
 }
 
-void App::loadSettings()
-{
-	// Setting 'Prefer Unscaled Tiles' to on is known to fail in the following
-	//  situation: The Keramik window decoration is in use AND caption bubbles
-	//  stick out above the title bar (i.e. Keramik's 'Draw small caption
-	// bubbles on active windows' configuration entry is set to off) AND the
-	// kshisen window is maximized.
-	//
-	// The user can work-around this situation by un-maximizing the window first.
-	if(Prefs::unscaled())
-	{
-		QSize s = board->unscaledSize();
-
-		// We would have liked to have used KMainWindow::sizeForCentralWidgetSize(),
-		// but this function does not seem to work when the toolbar is docked on the
-		// left. sizeForCentralWidgetSize() even reports a value 1 pixel too small
-		// when the toolbar is docked at the top...
-		// These bugs present in KDE: 3.1.90 (CVS >= 20030225)
-		//resize(sizeForCentralWidgetSize(s));
-
-		s += size() - board->size(); // compensate for chrome (toolbars, statusbars etc.)
-		resize(s);
-		//kdDebug() << "App::preferUnscaled() set size to: " << s.width() << " x " << s.height() << endl;
-	}
-}
-
 void App::lockMenus(bool lock)
 {
 	// Disable all actions apart from (un)pause, quit and those that are help-related.
 	// (Only undo/redo and hint actually *need* to be disabled, but disabling everything
 	// provides a good visual hint to the user, that they need to unpause to continue.
-	KPopupMenu* help = dynamic_cast<KPopupMenu*>(child("help", "KPopupMenu", false));
-	KActionPtrList actions = actionCollection()->actions();
-	KActionPtrList::iterator actionIter = actions.begin();
-	KActionPtrList::iterator actionIterEnd = actions.end();
+	KMenu* help = findChild<KMenu*>("help" );
+	QList<QAction*> actions = actionCollection()->actions();
+	QList<QAction*>::const_iterator actionIter = actions.begin();
+	QList<QAction*>::const_iterator actionIterEnd = actions.end();
 
 	while(actionIter != actionIterEnd)
 	{
-		KAction* a = *actionIter;
-		if(!a->isPlugged(help))
+		QAction* a = *actionIter;
+		if(!a->associatedWidgets().contains(help))
 			a->setEnabled(!lock);
 		++actionIter;
 	}
 
-	actionCollection()->action(KStdGameAction::name(KStdGameAction::Pause))->setEnabled(true);
-	actionCollection()->action(KStdGameAction::name(KStdGameAction::Quit))->setEnabled(true);
+	actionCollection()->action(KStandardGameAction::name(KStandardGameAction::Pause))->setEnabled(true);
+	actionCollection()->action(KStandardGameAction::name(KStandardGameAction::Quit))->setEnabled(true);
 
 	enableItems();
 }
@@ -250,23 +250,12 @@ void App::enableItems()
 {
 	if(!board->isPaused())
 	{
-		actionCollection()->action(KStdGameAction::name(KStdGameAction::Undo))->setEnabled(board->canUndo());
-		actionCollection()->action(KStdGameAction::name(KStdGameAction::Redo))->setEnabled(board->canRedo());
-		actionCollection()->action(KStdGameAction::name(KStdGameAction::Restart))->setEnabled(board->canUndo());
+		actionCollection()->action(KStandardGameAction::name(KStandardGameAction::Undo))->setEnabled(board->canUndo());
+		actionCollection()->action(KStandardGameAction::name(KStandardGameAction::Redo))->setEnabled(board->canRedo());
+		actionCollection()->action(KStandardGameAction::name(KStandardGameAction::Restart))->setEnabled(board->canUndo());
 	}
 }
 
-void App::boardResized()
-{
-	// If the board has been resized to a size that requires scaled tiles, then the
-	// 'Prefer Unscaled Tiles' option should be set to off.
-
-	//kdDebug() << "App::boardResized " << b->width() << " x " << b->height() << endl;
-	bool unscaled = Prefs::unscaled();
-	if(unscaled && board->size() != board->unscaledSize())
-		Prefs::setUnscaled(false);
-}
-
 void App::slotEndOfGame()
 {
 	if(board->tilesLeft() > 0)
@@ -298,10 +287,15 @@ void App::slotEndOfGame()
 		}
 		else
 		{
-			QString s = i18n("Congratulations! You made it in %1:%2:%3")
-				.arg(QString().sprintf("%02d", board->getTimeForGame()/3600))
-				.arg(QString().sprintf("%02d", (board->getTimeForGame() / 60) % 60))
-				.arg(QString().sprintf("%02d", board->getTimeForGame() % 60));
+			QString s = i18n("Congratulations! You made it in %1:%2:%3",
+				 QString().sprintf("%02d", board->getTimeForGame()/3600),
+				 QString().sprintf("%02d", (board->getTimeForGame() / 60) % 60),
+				 QString().sprintf("%02d", board->getTimeForGame() % 60));
+
+			if(isHighscore) // player would have been in the hisghscores if he did not cheat
+			{
+				s += '\n' + i18n("You could have been in the higscores if you did not use Undo or Hint. Try without them next time.");
+			}
 
 			KMessageBox::information(this, s, i18n("End of Game"));
 		}
@@ -311,24 +305,51 @@ void App::slotEndOfGame()
 	board->newGame();
 }
 
+void App::notifySelectATile()
+{
+	gameTipLabel->setText(i18n("Select a tile"));
+}
+
+void App::notifySelectAMatchingTile()
+{
+	gameTipLabel->setText(i18n("Select a matching tile"));
+}
+
+void App::notifySelectAMove()
+{
+	gameTipLabel->setText(i18n("Select the move you want by clicking on the blue line"));
+}
+
+void App::notifyTilesDontMatch()
+{
+	gameTipLabel->setText(i18n("This tile did not match the one you selected"));
+}
+
+void App::notifyInvalidMove()
+{
+	gameTipLabel->setText(i18n("You cannot make this move"));
+}
+
 void App::updateScore()
 {
 	int t = board->getTimeForGame();
-	QString s = i18n(" Your time: %1:%2:%3 %4")
-		.arg(QString().sprintf("%02d", t / 3600 ))
-		.arg(QString().sprintf("%02d", (t / 60) % 60 ))
-		.arg(QString().sprintf("%02d", t % 60 ))
-		.arg(board->isPaused()?i18n("(Paused) "):QString::null);
+	QString s = i18n(" Your time: %1:%2:%3 %4",
+		 QString().sprintf("%02d", t / 3600 ),
+		 QString().sprintf("%02d", (t / 60) % 60 ),
+		 QString().sprintf("%02d", t % 60 ),
+		 board->isPaused()?i18n("(Paused) "):QString());
 
-	statusBar()->changeItem(s, SBI_TIME);
+	//statusBar()->changeItem(s, SBI_TIME);
+	gameTimerLabel->setText(s);
 
 	// Number of tiles
 	int tl = (board->x_tiles() * board->y_tiles());
-	s = i18n(" Removed: %1/%2 ")
-		.arg(QString().sprintf("%d", tl - board->tilesLeft()))
-		.arg(QString().sprintf("%d", tl ));
+	s = i18n(" Removed: %1/%2 ",
+		 QString().sprintf("%d", tl - board->tilesLeft()),
+		 QString().sprintf("%d", tl ));
 
-	statusBar()->changeItem(s, SBI_TILES);
+	//statusBar()->changeItem(s, SBI_TILES);
+	gameTilesLabel->setText(s);
 }
 
 void App::setCheatMode()
@@ -337,7 +358,7 @@ void App::setCheatMode()
 	if(!cheat)
 	{
 		cheat = true;
-		statusBar()->changeItem(i18n(" Cheat mode "), SBI_CHEAT);
+		gameCheatLabel->show();
 	}
 }
 
@@ -347,51 +368,41 @@ void App::resetCheatMode()
 	if(cheat)
 	{
 		cheat = false;
-		statusBar()->changeItem("", SBI_CHEAT);
+		gameCheatLabel->hide();
 	}
 }
 
 QString App::getPlayerName()
 {
-	QDialog *dlg = new QDialog(this, "Hall of Fame", true);
+	KDialog dlg(this);
+	dlg.setObjectName( "Hall of Fame" );
+	dlg.setButtons( KDialog::Ok );
 
-	QLabel  *l1  = new QLabel(i18n("You've made it into the \"Hall Of Fame\". Type in\nyour name so mankind will always remember\nyour cool rating."), dlg);
-	l1->setFixedSize(l1->sizeHint());
+	QWidget* dummy = new QWidget( &dlg );
+	dlg.setMainWidget( dummy );
 
-	QLabel *l2 = new QLabel(i18n("Your name:"), dlg);
-	l2->setFixedSize(l2->sizeHint());
+        QLabel *l1 = new QLabel(i18n("You have made it into the \"Hall Of Fame\". Type in\nyour name so mankind will always remember\nyour cool rating."), dummy);
 
-	QLineEdit *e = new QLineEdit(dlg);
-	e->setText("XXXXXXXXXXXXXXXX");
-	e->setMinimumWidth(e->sizeHint().width());
-	e->setFixedHeight(e->sizeHint().height());
+	QLabel *l2 = new QLabel(i18n("Your name:"), dummy);
+
+	KLineEdit *e = new KLineEdit( dummy );
+	e->setMinimumWidth( e->fontMetrics().width( "XXXXXXXXXXXXXXXX" ) );
 	e->setText( lastPlayerName );
 	e->setFocus();
 
-	QPushButton *b = new KPushButton(KStdGuiItem::ok(), dlg);
-	b->setDefault(true);
-	b->setFixedSize(b->sizeHint());
-
-	connect(b, SIGNAL(released()), dlg, SLOT(accept()));
-	connect(e, SIGNAL(returnPressed()), dlg, SLOT(accept()));
-
 	// create layout
-	QVBoxLayout *tl = new QVBoxLayout(dlg, 10);
-	QHBoxLayout *tl1 = new QHBoxLayout();
-	tl->addWidget(l1);
-	tl->addSpacing(5);
-	tl->addLayout(tl1);
+	QHBoxLayout *tl1 = new QHBoxLayout;
 	tl1->addWidget(l2);
 	tl1->addWidget(e);
-	tl->addSpacing(5);
-	tl->addWidget(b);
-	tl->activate();
-	tl->freeze();
+	QVBoxLayout *tl = new QVBoxLayout( dummy );
+	tl->setMargin( 10 );
+	tl->setSpacing( 5 );
+	tl->addWidget(l1);
+	tl->addLayout(tl1);
 
-	dlg->exec();
+	dlg.exec();
 
 	lastPlayerName = e->text();
-	delete dlg;
 
 	if(lastPlayerName.isEmpty())
 		return " ";
@@ -479,7 +490,7 @@ void App::readHighscore()
 
 	highscore.resize(0);
 
-	for (unsigned int i = 0; i < hi_x.count(); i++)
+	for (int i = 0; i < hi_x.count(); i++)
 	{
 		highscore.resize(i+1);
 
@@ -501,40 +512,39 @@ void App::readOldHighscore()
 {
 	// this is for before-KHighscore-highscores
 	int i;
-	QString s, e, grp;
-	KConfig *conf = kapp->config();
+	QString s, e;
+	KSharedConfig::Ptr conf = KGlobal::config();
 
 	highscore.resize(0);
 	i = 0;
 	bool eol = false;
-	grp = conf->group();
-	conf->setGroup("Hall of Fame");
+	KConfigGroup group = conf->group("Hall of Fame");
 	while ((i < (int)HIGHSCORE_MAX) && !eol)
 	{
 		s.sprintf("Highscore_%d", i);
-		if(conf->hasKey(s))
+		if(group.hasKey(s))
 		{
-			e = conf->readEntry(s);
+			e = group.readEntry(s,QString());
 			highscore.resize(i+1);
 
 			HighScore hs;
 
-			QStringList e = conf->readListEntry(s, ' ');
+			QStringList e = group.readEntry(s, QString()).split(' ');
 			int nelem = e.count();
-			hs.x = (*e.at(0)).toInt();
-			hs.y = (*e.at(1)).toInt();
-			hs.seconds = (*e.at(2)).toInt();
-			hs.date = (*e.at(3)).toInt();
+			hs.x = e.at(0).toInt();
+			hs.y = e.at(1).toInt();
+			hs.seconds = e.at(2).toInt();
+			hs.date = e.at(3).toInt();
 
 			if(nelem == 4) // old version <= 1.1
 			{
 				hs.gravity = 0;
-				hs.name = *e.at(4);
+				hs.name = e.at(4);
 			}
 			else
 			{
-				hs.gravity = (*e.at(4)).toInt();
-				hs.name = *e.at(5);
+				hs.gravity = e.at(4).toInt();
+				hs.name = e.at(5);
 			}
 
 			highscore[i] = hs;
@@ -558,9 +568,6 @@ void App::readOldHighscore()
 //		highscore[0] = hs;
 //	}
 
-	// restore old group
-	conf->setGroup(grp);
-
 	// write in new KHighscore format
 	writeHighscore();
 	// read form KHighscore format
@@ -587,62 +594,62 @@ void App::writeHighscore()
 	highscoreTable->writeList("date", hi_date);
 	highscoreTable->writeList("gravity", hi_grav);
 	highscoreTable->writeList("name", hi_name);
-	highscoreTable->sync();
+	highscoreTable->writeAndUnlock();
 }
 
 void App::showHighscore(int focusitem)
 {
 	// this may look a little bit confusing...
-	QDialog *dlg = new QDialog(0, "hall_Of_fame", true);
-	dlg->setCaption(i18n("Hall of Fame"));
+	KDialog dlg;
+	dlg.setObjectName( "hall_Of_fame" );
+	dlg.setButtons( KDialog::Close );
+	dlg.setWindowTitle(i18n("Hall of Fame"));
 
-	QVBoxLayout *tl = new QVBoxLayout(dlg, 10);
+	QWidget* dummy = new QWidget(&dlg);
+	dlg.setMainWidget(dummy);
 
-	QLabel *l = new QLabel(i18n("Hall of Fame"), dlg);
+	QVBoxLayout *tl = new QVBoxLayout(dummy);
+	tl->setMargin( 10 );
+
+	QLabel *l = new QLabel(i18n("Hall of Fame"), dummy);
 	QFont f = font();
 	f.setPointSize(24);
 	f.setBold(true);
 	l->setFont(f);
-	l->setFixedSize(l->sizeHint());
-	l->setFixedWidth(l->width() + 32);
-	l->setAlignment(AlignCenter);
+	l->setAlignment(Qt::AlignCenter);
 	tl->addWidget(l);
 
 	// insert highscores in a gridlayout
-	QGridLayout *table = new QGridLayout(12, 5, 5);
+	QGridLayout *table = new QGridLayout;
+	tl->setSpacing(5);
 	tl->addLayout(table, 1);
 
 	// add a separator line
-	KSeparator *sep = new KSeparator(dlg);
-	table->addMultiCellWidget(sep, 1, 1, 0, 4);
+	KSeparator *sep = new KSeparator(dummy);
+	table->addWidget(sep, 1, 0, 1, 5);
 
 	// add titles
 	f = font();
 	f.setBold(true);
-	l = new QLabel(i18n("Rank"), dlg);
+	l = new QLabel(i18n("Rank"), dummy);
 	l->setFont(f);
-	l->setMinimumSize(l->sizeHint());
 	table->addWidget(l, 0, 0);
-	l = new QLabel(i18n("Name"), dlg);
+	l = new QLabel(i18n("Name"), dummy);
 	l->setFont(f);
-	l->setMinimumSize(l->sizeHint());
 	table->addWidget(l, 0, 1);
-	l = new QLabel(i18n("Time"), dlg);
+	l = new QLabel(i18n("Time"), dummy);
 	l->setFont(f);
-	l->setMinimumSize(l->sizeHint());
 	table->addWidget(l, 0, 2);
-	l = new QLabel(i18n("Size"), dlg);
+	l = new QLabel(i18n("Size"), dummy);
 	l->setFont(f);
-	l->setMinimumSize(l->sizeHint());
 	table->addWidget(l, 0, 3);
-	l = new QLabel(i18n("Score"), dlg);
+	l = new QLabel(i18n("Score"), dummy);
 	l->setFont(f);
-	l->setMinimumSize(l->sizeHint().width()*3, l->sizeHint().height());
 	table->addWidget(l, 0, 4);
 
 	QString s;
 	QLabel *e[10][5];
-	unsigned i, j;
+	signed i, j;
 
 	for(i = 0; i < 10; i++)
 	{
@@ -652,13 +659,13 @@ void App::showHighscore(int focusitem)
 
 		// insert rank
 		s.sprintf("%d", i+1);
-		e[i][0] = new QLabel(s, dlg);
+		e[i][0] = new QLabel(s, dummy);
 
 		// insert name
 		if(i < highscore.size())
-			e[i][1] = new QLabel(hs.name, dlg);
+			e[i][1] = new QLabel(hs.name, dummy);
 		else
-			e[i][1] = new QLabel("", dlg);
+			e[i][1] = new QLabel("", dummy);
 
 		// insert time
 		QTime ti(0,0,0);
@@ -666,11 +673,11 @@ void App::showHighscore(int focusitem)
 		{
 			ti = ti.addSecs(hs.seconds);
 			s.sprintf("%02d:%02d:%02d", ti.hour(), ti.minute(), ti.second());
-			e[i][2] = new QLabel(s, dlg);
+			e[i][2] = new QLabel(s, dummy);
 		}
 		else
 		{
-			e[i][2] = new QLabel("", dlg);
+			e[i][2] = new QLabel("", dummy);
 		}
 
 		// insert size
@@ -679,7 +686,7 @@ void App::showHighscore(int focusitem)
 		else
 			s = "";
 
-		e[i][3] = new QLabel(s, dlg);
+		e[i][3] = new QLabel(s, dummy);
 
 		// insert score
 		if(i < highscore.size())
@@ -693,8 +700,8 @@ void App::showHighscore(int focusitem)
 			s = "";
 		}
 
-		e[i][4] = new QLabel(s, dlg);
-		e[i][4]->setAlignment(AlignRight);
+		e[i][4] = new QLabel(s, dummy);
+		e[i][4]->setAlignment(Qt::AlignRight);
 	}
 
 	f = font();
@@ -704,42 +711,20 @@ void App::showHighscore(int focusitem)
 	{
 		for(j = 0; j < 5; j++)
 		{
-			e[i][j]->setMinimumHeight(e[i][j]->sizeHint().height());
-
-			if(j == 1)
-				e[i][j]->setMinimumWidth(std::max(e[i][j]->sizeHint().width(), 100));
-			else
-				e[i][j]->setMinimumWidth(std::max(e[i][j]->sizeHint().width(), 60));
-
 			if((int)i == focusitem)
 				e[i][j]->setFont(f);
 
-			table->addWidget(e[i][j], i+2, j, AlignCenter);
+			table->addWidget(e[i][j], i+2, j, Qt::AlignCenter);
 		}
 	}
 
-	QPushButton *b = new KPushButton(KStdGuiItem::close(), dlg);
-
-	b->setFixedSize(b->sizeHint());
-
-	// connect the "Close"-button to done
-	connect(b, SIGNAL(clicked()), dlg, SLOT(accept()));
-	b->setDefault(true);
-	b->setFocus();
-
-	// make layout
-	tl->addSpacing(10);
-	tl->addWidget(b);
-	tl->activate();
-	tl->freeze();
-
-	dlg->exec();
-	delete dlg;
+	dlg.exec();
 }
 
 void App::keyBindings()
 {
-	KKeyDialog::configure(actionCollection(), this);
+	KShortcutsDialog::configure( actionCollection(), KShortcutsEditor::LetterShortcutsAllowed, this );
+
 }
 
 /**
@@ -748,12 +733,14 @@ void App::keyBindings()
 void App::showSettings(){
 	if(KConfigDialog::showDialog("settings"))
 		return;
-
-	KConfigDialog *dialog = new KConfigDialog(this, "settings", Prefs::self(), KDialogBase::Swallow);
-	Settings *general = new Settings(0, "General");
-	dialog->addPage(general, i18n("General"), "package_settings");
-	connect(dialog, SIGNAL(settingsChanged()), this, SLOT(loadSettings()));
-	connect(dialog, SIGNAL(settingsChanged()), board, SLOT(loadSettings()));
+	
+	//Use the classes exposed by LibKmahjongg for our configuration dialog
+	KMahjonggConfigDialog *dialog = new KMahjonggConfigDialog(this, "settings", Prefs::self());
+	dialog->addPage(new Settings(0), i18n("General"), "games-config-options");
+	dialog->addTilesetPage();
+	dialog->addBackgroundPage();
+        dialog->setHelp(QString(),"kshisen");
+	connect(dialog, SIGNAL(settingsChanged(const QString &)), board, SLOT(loadSettings()));
 	dialog->show();
 }
 
