@@ -13,35 +13,37 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 #ifndef __KCHAT_H__
 #define __KCHAT_H__
 
-#include <qstring.h>
-
 #include "kchatbase.h"
+#include <libkdegames_export.h>
 
 class KChatPrivate;
 
 /**
- * A chat widget for non-KGame use.
+ * \class KChat kchat.h <KChat>
+ * 
+ * @short A chat widget for non-KGame games
  *
  * Docu is TODO
- * @short A chat widget for non-KGame games
+ *
  * @author Andreas Beckermann <b_mann@gmx.de>
  **/
-class KChat : public KChatBase
+class KDEGAMES_EXPORT KChat : public KChatBase
 {
 	Q_OBJECT
 public:
 	/**
+	 * @param parent The parent widget for this widget.
 	 * @param twoPlayerGame If true the combo box where the player can
 	 * choose to send to a single player or to all players will not be added
-	 * as you will hardly need it in 2-player games...
+	 * as you will hardly need it in 2-player games.
 	 **/
-	KChat(QWidget* parent, bool twoPlayerGame = false);
+	explicit KChat(QWidget* parent, bool twoPlayerGame = false);
 
 	virtual ~KChat();
 
@@ -50,12 +52,12 @@ public:
 	 * @return The name that will be shown for messages from this widget.
 	 * That is the string from @ref setFromNickname
 	 **/
-	virtual const QString& fromName() const;
+	virtual QString fromName() const;
 
 	/**
 	 * This sets the name that will be shown on all chat widgets if this
-	 * widget sends a message. See @ref signalSendMessage
-	 * @ref The name of the player owning this widget
+	 * widget sends a message. See signalSendMessage
+	 * @param name The name of the player owning this widget
 	 **/
 	void setFromNickname(const QString& name);
 
@@ -103,22 +105,23 @@ public:
 	/**
 	 * @return The nickname of the player which belongs to this id
 	 **/
-	const QString& player(int id) const;
+	QString player(int id) const;
 
 	/**
-	 * @return The ID that belongs to the local player. See @setFromNickname
+	 * @return The ID that belongs to the local player. 
+	 * @see setFromNickname
 	 **/
 	int fromId() const;
 	
 
-signals:
+Q_SIGNALS:
 	/**
 	 * This signal is emitted when the player wants to send a message.
 	 *
 	 * The message is added automatically using @ref KChatBase::addMessage if @ref
 	 * autoAddMessages is enabled.
 	 * @param id The id of the player who sends the message - see
-	 * @ref setFromNickname and @ref player
+	 * setFromNickname and player
 	 * @param msg The message itself
 	 **/
 	void signalSendMessage(int id, const QString& msg);
@@ -138,7 +141,7 @@ protected:
 private:
 	void init();
 
-	KChatPrivate* d;
+	KChatPrivate* const d;
 };
 
 #endif
