@@ -1,6 +1,6 @@
 /*
     This file is part of the KDE games library
-    Copyright (C) 2001 Martin Heni (martin@heni-online.de)
+    Copyright (C) 2001 Martin Heni (kde at heni-online.de)
     Copyright (C) 2001 Andreas Beckermann (b_mann@gmx.de)
 
     This library is free software; you can redistribute it and/or
@@ -17,15 +17,14 @@
     the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
     Boston, MA 02110-1301, USA.
 */
-/*
-    $Id: kgamenetwork.h 465369 2005-09-29 14:33:08Z mueller $
-*/
+
 #ifndef __KGAMENETWORK_H_
 #define __KGAMENETWORK_H_
 
-#include <qstring.h>
-#include <qobject.h>
-#include <kdemacros.h>
+#include <QtCore/QString>
+#include <QtCore/QObject>
+#include <libkdegames_export.h>
+
 class KGameIO;
 class KMessageClient;
 class KMessageServer;
@@ -33,6 +32,8 @@ class KMessageServer;
 class KGameNetworkPrivate;
 
 /**
+ * \class KGameNetwork kgamenetwork.h <KGame/KGameNetwork>
+ * 
  * The KGameNetwork class is the KGame class with network
  * support. All other features are the same but they are
  * now network transparent. It is not used directly but
@@ -40,10 +41,8 @@ class KGameNetworkPrivate;
  * to bother with this object.
  *
  * @short The main KDE game object
- * @author Martin Heni <martin@heni-online.de>
- * @version $Id: kgamenetwork.h 465369 2005-09-29 14:33:08Z mueller $
  */
-class KDE_EXPORT KGameNetwork : public QObject
+class KDEGAMES_EXPORT KGameNetwork : public QObject
 {
   Q_OBJECT
 
@@ -51,7 +50,7 @@ public:
     /**
      * Create a KGameNetwork object
      */
-    KGameNetwork(int cookie=42,QObject* parent=0);
+    explicit KGameNetwork(int cookie=42,QObject* parent=0);
     virtual ~KGameNetwork();
 
     /**
@@ -96,7 +95,7 @@ public:
      *
      * @return int id
      **/
-    Q_UINT32 gameId() const;
+    quint32 gameId() const;
 
     /**
      * Inits a network game as network MASTER. Note that if the
@@ -108,19 +107,9 @@ public:
      * @param port The port on which the service is offered
      * @return true if it worked
      **/
-    bool offerConnections (Q_UINT16 port);
-    
-    /**
-     * Announces game MASTER on network using DNS-SD. Clients then can discover it using
-     * DNSSD::ServiceBrowser (or KGameConnectWidget) instead of manually entering 
-     * IP address.
-     * @param type service type (something like _kwin4._tcp). 
-     * It should be unique for application.
-     * @param name game name that will be displayed by clients.  If not
-     * set hostname will be used. In case of name conflict -2, -3 and so on will be added to name.
-     * @since 3.4
-     **/
-    void setDiscoveryInfo(const QString& type, const QString& name=QString::null);
+    bool offerConnections (quint16 port);
+
+    void setDiscoveryInfo(const QString& type, const QString& name=QString());
     
     /**
      * Inits a network game as a network CLIENT
@@ -130,18 +119,16 @@ public:
      *
      * @return true if connected
      **/
-    bool connectToServer(const QString& host, Q_UINT16 port);
+    bool connectToServer(const QString& host, quint16 port);
 
     /**
-     * @since 3.2
      * @return The port we are listening to if offerConnections was called
      * or the port we are connected to if connectToServer was called.
      * Otherwise 0.
      **/
-    Q_UINT16 port() const;
+    quint16 port() const;
 
     /**
-     * @since 3.2
      * @return The name of the host that we are currently connected to is
      * isNetwork is TRUE and we are not the MASTER, i.e. if connectToServer
      * was called. Otherwise this will return "localhost".
@@ -189,22 +176,22 @@ public:
      * @return true if worked
      */
     // AB: TODO: doc on how "receiver" and "sender" should be created!
-    bool sendSystemMessage(const QByteArray& buffer, int msgid, Q_UINT32 receiver=0, Q_UINT32 sender=0);
+    bool sendSystemMessage(const QByteArray& buffer, int msgid, quint32 receiver=0, quint32 sender=0);
 
     /**
      * @overload
      **/
-    bool sendSystemMessage(int data, int msgid, Q_UINT32 receiver=0, Q_UINT32 sender=0);
+    bool sendSystemMessage(int data, int msgid, quint32 receiver=0, quint32 sender=0);
 
     /**
      * @overload
      **/
-    bool sendSystemMessage(const QDataStream &msg, int msgid, Q_UINT32 receiver=0, Q_UINT32 sender=0);
+    bool sendSystemMessage(const QDataStream &msg, int msgid, quint32 receiver=0, quint32 sender=0);
 
     /**
      * @overload
      **/
-    bool sendSystemMessage(const QString& msg, int msgid, Q_UINT32 receiver=0, Q_UINT32 sender=0);
+    bool sendSystemMessage(const QString& msg, int msgid, quint32 receiver=0, quint32 sender=0);
 
     /**
      * Sends a network message
@@ -217,7 +204,7 @@ public:
      * the correct value for you. You might want to use this if you send a 
      * message from a specific player.
      **/
-    void sendError(int error, const QByteArray& message, Q_UINT32 receiver=0, Q_UINT32 sender=0);
+    void sendError(int error, const QByteArray& message, quint32 receiver=0, quint32 sender=0);
 
     /**
      * Are we still offer offering server connections - only for game MASTER
@@ -265,29 +252,29 @@ public:
      * @return true if worked
      **/
     // AB: TODO: doc on how "receiver" and "sender" should be created!
-    bool sendMessage(const QByteArray& buffer, int msgid, Q_UINT32 receiver=0, Q_UINT32 sender=0);
+    bool sendMessage(const QByteArray& buffer, int msgid, quint32 receiver=0, quint32 sender=0);
 
     /**
      * This is an overloaded member function, provided for convenience.
      **/
-    bool sendMessage(const QDataStream &msg, int msgid, Q_UINT32 receiver=0, Q_UINT32 sender=0);
+    bool sendMessage(const QDataStream &msg, int msgid, quint32 receiver=0, quint32 sender=0);
 
     /**
      * This is an overloaded member function, provided for convenience.
      **/
-    bool sendMessage(const QString& msg, int msgid, Q_UINT32 receiver=0, Q_UINT32 sender=0);
+    bool sendMessage(const QString& msg, int msgid, quint32 receiver=0, quint32 sender=0);
 
     /**
      * This is an overloaded member function, provided for convenience.
      **/
-    bool sendMessage(int data, int msgid, Q_UINT32 receiver=0, Q_UINT32 sender=0);
+    bool sendMessage(int data, int msgid, quint32 receiver=0, quint32 sender=0);
 
 
     /**
      * Called by ReceiveNetworkTransmission(). Will be overwritten by
      * KGame and handle the incoming message.
      **/
-    virtual void networkTransmission(QDataStream&, int, Q_UINT32, Q_UINT32, Q_UINT32 clientID) = 0;
+    virtual void networkTransmission(QDataStream&, int, quint32, quint32, quint32 clientID) = 0;
 
 
     /**
@@ -304,7 +291,7 @@ public:
      * @param clientID the ID of the new ADMIN (note: this is the _client_ID
      * which has nothing to do with the player IDs. See KMessageServer)
      **/
-    void electAdmin(Q_UINT32 clientID);
+    void electAdmin(quint32 clientID);
 
     /**
      * Don't use this unless you really know what youre doing! You might
@@ -339,7 +326,7 @@ public:
      **/
     virtual void unlock();
 
-signals:
+Q_SIGNALS:
     /**
      * A network error occurred
      * @param error the error code
@@ -362,7 +349,7 @@ signals:
      *
      * @param clientID the ID of the newly connected client
      **/
-    void signalClientConnected(Q_UINT32 clientID);
+    void signalClientConnected(quint32 clientID);
 
     /**
      * This signal is emitted whenever the KMessageServer sends us a message
@@ -375,7 +362,7 @@ signals:
      * @param broken true if the connection was lost because of a network error, false
      *        if the connection was closed by the message server admin.
      */
-    void signalClientDisconnected(Q_UINT32 clientID, bool broken);
+    void signalClientDisconnected(quint32 clientID, bool broken);
 
     /**
      * This client gets or loses the admin status.
@@ -393,7 +380,7 @@ protected:
      **/
     void setMaster();
 
-protected slots:
+protected Q_SLOTS:
     /**
      * Called by KMessageClient::broadcastReceived() and will check if the
      * message format is valid. If it is not, it will generate an error (see
@@ -401,7 +388,7 @@ protected slots:
      * If it is valid, the pure virtual method networkTransmission() is called.
      * (This one is overwritten in KGame.)
      **/
-    void receiveNetworkTransmission(const QByteArray& a, Q_UINT32 clientID);
+    void receiveNetworkTransmission(const QByteArray& a, quint32 clientID);
 
     /**
      * This KGame object receives or loses the admin status.
@@ -413,7 +400,7 @@ protected slots:
      * Called when the network connection is about to terminate. Is used
      * to store the network parameter like the game id
      */
-     void aboutToLoseConnection(Q_UINT32 id);
+     void aboutToLoseConnection(quint32 id);
 
     /**
      * Called when the network connection is terminated. Used to clean
@@ -425,7 +412,7 @@ protected slots:
 private:
      void tryPublish();
      void tryStopPublishing();
-     KGameNetworkPrivate* d;
+     KGameNetworkPrivate* const d;
 };
 
 #endif
